The Foos and The Bars - Alt

1. # A Limerick

       There was an old man from Nantucket
       Who kept all his cash in a bucket,
       His daughter, called Nan, ran away with a man,
       And as for the bucket - Nantucket!

2. # A Series of unfortunate blogs

   I woke up this morning to discover that I had turned into a rather large root vegetable, possibly a turnip or parsnip, it was hard to tell.

   ## What happened next

   Reader, they pureed me!

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter